==> jc-1.4.0.tar.gz: java__5fcup/lalr__5fstate__24Path.h <==
// class java_cup.lalr_state$Path

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76d43c101439dff6 java__5fcup_lalr__5fstate__24Path

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5fstate__24Path_H_
#define _JC_java__5fcup_lalr__5fstate__24Path_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_lalr__5fstate__24StateItem$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$sub_refs	_jc_java__5fcup_lalr__5fstate__24Path$sub_refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs	_jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$refs	_jc_java__5fcup_lalr__5fstate__24Path$refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$nonrefs	_jc_java__5fcup_lalr__5fstate__24Path$nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$object	_jc_java__5fcup_lalr__5fstate__24Path$object;

typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vmethods	_jc_java__5fcup_lalr__5fstate__24Path$vmethods;
typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vtable	_jc_java__5fcup_lalr__5fstate__24Path$vtable;
typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vtype	_jc_java__5fcup_lalr__5fstate__24Path$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5fstate__24Path$method$_init$1f764d28bf384a2d(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24Path$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java_util_LinkedList$object *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *);

// Virtual methods structure
struct _jc_java__5fcup_lalr__5fstate__24Path$vmethods {
};

// Vtable
struct _jc_java__5fcup_lalr__5fstate__24Path$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5fstate__24Path$vmethods	java__5fcup_lalr__5fstate__24Path;
};

// Vtype
struct _jc_java__5fcup_lalr__5fstate__24Path$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5fstate__24Path$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24Path$sub_refs {
	struct _jc_java_util_LinkedList$object	*steps;
	struct _jc_java__5fcup_lalr__5fstate__24StateItem$object	*last;
	struct _jc_java__5fcup_lalr__5fstate$object	*this__240;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24Path$refs {
    _jc_java__5fcup_lalr__5fstate__24Path$sub_refs	java__5fcup_lalr__5fstate__24Path;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24Path$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs	java__5fcup_lalr__5fstate__24Path;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5fstate__24Path$object {
	_jc_java__5fcup_lalr__5fstate__24Path$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5fstate__24Path$vtype	*vtype;
	_jc_java__5fcup_lalr__5fstate__24Path$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5fstate__24Path$vtype _jc_java__5fcup_lalr__5fstate__24Path$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5fstate__24Path, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5fstate__24Path$class_object;

#endif	/* _JC_java__5fcup_lalr__5fstate__24Path_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/lalr__5fstate__24Path.h <==
// class java_cup.lalr_state$Path

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76d43c101439dff6 java__5fcup_lalr__5fstate__24Path

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5fstate__24Path_H_
#define _JC_java__5fcup_lalr__5fstate__24Path_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_lalr__5fstate__24StateItem$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$sub_refs	_jc_java__5fcup_lalr__5fstate__24Path$sub_refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs	_jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$refs	_jc_java__5fcup_lalr__5fstate__24Path$refs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$nonrefs	_jc_java__5fcup_lalr__5fstate__24Path$nonrefs;
typedef struct _jc_java__5fcup_lalr__5fstate__24Path$object	_jc_java__5fcup_lalr__5fstate__24Path$object;

typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vmethods	_jc_java__5fcup_lalr__5fstate__24Path$vmethods;
typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vtable	_jc_java__5fcup_lalr__5fstate__24Path$vtable;
typedef const struct _jc_java__5fcup_lalr__5fstate__24Path$vtype	_jc_java__5fcup_lalr__5fstate__24Path$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5fstate__24Path$method$_init$1f764d28bf384a2d(_jc_env *, struct _jc_java__5fcup_lalr__5fstate__24Path$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java_util_LinkedList$object *, struct _jc_java__5fcup_lalr__5fstate__24StateItem$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_lalr__5fstate__24Path$vmethods {
};

// Vtable
struct _jc_java__5fcup_lalr__5fstate__24Path$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5fstate__24Path$vmethods	java__5fcup_lalr__5fstate__24Path;
};

// Vtype
struct _jc_java__5fcup_lalr__5fstate__24Path$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5fstate__24Path$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24Path$sub_refs {
	struct _jc_java_util_LinkedList$object	*steps;
	struct _jc_java__5fcup_lalr__5fstate__24StateItem$object	*last;
	struct _jc_java__5fcup_lalr__5fstate$object	*this__240;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24Path$refs {
    _jc_java__5fcup_lalr__5fstate__24Path$sub_refs	java__5fcup_lalr__5fstate__24Path;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5fstate__24Path$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5fstate__24Path$sub_nonrefs	java__5fcup_lalr__5fstate__24Path;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5fstate__24Path$object {
	_jc_java__5fcup_lalr__5fstate__24Path$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5fstate__24Path$vtype	*vtype;
	_jc_java__5fcup_lalr__5fstate__24Path$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5fstate__24Path$vtype _jc_java__5fcup_lalr__5fstate__24Path$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5fstate__24Path, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5fstate__24Path$class_object;

#endif	/* _JC_java__5fcup_lalr__5fstate__24Path_H_ */
